// Konfigurationsvariablen
const useSpanElements = true; // true: span-Elemente, false: headline-menu-item-content-Elemente
const gapOffset = 20; // Pixeloffset für jeden Zwischenraum
const globalOffset = 100; // Globaler, fixer Offset

let breakpoint = 0; // Variable zur Speicherung des Umbruchpunkts

// Funktion zum Ermitteln der Breite eines ausgeblendeten Elements
function getHiddenElementWidth(element) {
  var clone = element.cloneNode(true);
  clone.style.visibility = 'hidden';
  clone.style.display = 'inline-block';
  document.body.appendChild(clone);
  var style = window.getComputedStyle(clone);
  var width = clone.offsetWidth + parseInt(style.marginLeft) + parseInt(style.marginRight) + parseInt(style.paddingLeft) + parseInt(style.paddingRight);
  document.body.removeChild(clone);
  return width;
}

// Funktion zum Überprüfen der Menübreite und Umschalten des Hamburger-Menüs
// Funktion zum Überprüfen der Menübreite und Umschalten des Hamburger-Menüs
function checkMenuWidth() {
  var headlineMenu = document.getElementById('headline-menu');
  var hamburgerIcon = document.getElementById('hamburger-icon-container');
  var menuItems;

  if (useSpanElements) {
    menuItems = document.querySelectorAll('.headline-menu-item-content > span');
  } else {
    menuItems = document.querySelectorAll('.headline-menu-item-content');
  }

  var totalWidth = 0;
  var visibleItems = 0;

  // Breite der einzelnen Menüpunkte ermitteln und addieren
  menuItems.forEach(function (item) {
    var itemWidth = getHiddenElementWidth(item);
    if (itemWidth > 0) {
      totalWidth += itemWidth;
      visibleItems++;
    }
  });

  // Anzahl der Zwischenräume berechnen und Offset hinzufügen
  var gapCount = visibleItems - 1;
  var gapWidth = gapCount * gapOffset;
  totalWidth += gapWidth + globalOffset;

  // Breite des Hamburger-Icon-Containers hinzufügen
  var hamburgerIconWidth = hamburgerIcon.offsetWidth;
  totalWidth += hamburgerIconWidth;

  // Verfügbare Breite des Webbrowsers ermitteln
  var availableWidth = window.innerWidth;

  // Umbruchpunkt speichern, wenn er noch nicht gesetzt ist
  if (breakpoint === 0) {
    breakpoint = totalWidth;
  }

  // console.log("Total width: " + totalWidth);
  // console.log("Available width: " + availableWidth);
  // console.log("Breakpoint: " + breakpoint);
  // console.log("Browser width: " + window.innerWidth);

  // Vergleichen und umschalten
  if (availableWidth < breakpoint) {
    headlineMenu.style.display = 'none';
  } else {
    headlineMenu.style.display = 'flex';
    // Einblenden des Headline-Menüs nur, wenn die Deckkraft unter 1.0 liegt
    var opacity = parseFloat(window.getComputedStyle(headlineMenu).getPropertyValue('opacity'));
    if (isNaN(opacity) || opacity < 1.0) {
      fadeInHeadlineMenu();
    }
  }
}

// Funktion zum Einblenden des Headline-Menüs
function fadeInHeadlineMenu() {
  var headlineMenu = document.getElementById('headline-menu');
  var opacity = 0;
  var interval = setInterval(function() {
    if (opacity >= 1) {
      clearInterval(interval);
      headlineMenu.style.opacity = '1';
    } else {
      opacity += 0.1;
      headlineMenu.style.opacity = opacity.toFixed(1);
    }
  }, 20);
}

// Event-Listener für das Ändern der Fensterbreite
window.addEventListener('resize', checkMenuWidth);

// Einmalige Überprüfung und Einblenden beim Laden der Seite
window.addEventListener('load', function() {
  checkMenuWidth();
  fadeInHeadlineMenu();
});
